import NavigationCollections from './collections/index.js';
import { filterItemsByLocale, formatNavigation } from './utils/index.js';
export const navigationPlugin = (pluginOptions = {})=>(config)=>{
        // Setup collections array if it doesn't exist
        if (!config.collections) {
            config.collections = [];
        }
        // Add navigation collections
        config.collections.push(...NavigationCollections);
        // Configure collection references based on plugin options
        if (pluginOptions.collections) {
            // Find the navigation item collection
            const navigationItemCollection = config.collections.find((collection)=>collection.slug === 'navigation-items');
            if (navigationItemCollection) {
                // Get the internalLink group field
                const fields = navigationItemCollection.fields;
                const internalLinkGroup = fields.find((field)=>field.name === 'internalLink');
                if (internalLinkGroup && internalLinkGroup.fields) {
                    // Find the reference field
                    const referenceField = internalLinkGroup.fields.find((field)=>field.name === 'reference');
                    if (referenceField) {
                        // Update relationTo to include all configured collections
                        referenceField.relationTo = Object.keys(pluginOptions.collections);
                    }
                }
            }
        }
        /**
     * If the plugin is disabled, we still want to keep added collections/fields
     * for database schema consistency which is important for migrations.
     */ if (pluginOptions.disabled) {
            return config;
        }
        // Set up endpoints if they don't exist
        if (!config.endpoints) {
            config.endpoints = [];
        }
        // Set up admin if it doesn't exist
        if (!config.admin) {
            config.admin = {};
        }
        // Set up admin components if they don't exist
        if (!config.admin.components) {
            config.admin.components = {};
        }
        // Add plugin to admin navigation
        // @ts-ignore - Adding nav to admin config
        if (!config.admin.nav) {
            // @ts-ignore - Adding nav to admin config
            config.admin.nav = [];
        }
        // @ts-ignore - Adding nav to admin config
        config.admin.nav = [
            // @ts-ignore - Adding nav to admin config
            ...Array.isArray(config.admin.nav) ? config.admin.nav : [],
            {
                type: 'group',
                items: [
                    {
                        label: 'Containers',
                        path: '/admin/collections/navigation-containers'
                    },
                    {
                        label: 'Items',
                        path: '/admin/collections/navigation-items'
                    }
                ],
                label: 'Navigation'
            }
        ];
        // Add API endpoints
        config.endpoints.push({
            method: 'get',
            path: '/api/navigation',
            // @ts-ignore - Endpoint handler type mismatch
            handler: async (req, res, next)=>{
                const payload = req.payload;
                const { locale } = req.query;
                try {
                    const result = await payload.find({
                        collection: 'navigation-containers',
                        ...locale ? {
                            locale
                        } : {}
                    });
                    res.status(200).json(result);
                } catch (error) {
                    next(error);
                }
            }
        }, {
            method: 'get',
            path: '/api/navigation/:slug',
            // @ts-ignore - Endpoint handler type mismatch
            handler: async (req, res, next)=>{
                const payload = req.payload;
                const { slug } = req.params;
                const { depth, format, includeHidden, item: currentItemId, locale } = req.query;
                try {
                    // Find the navigation container
                    const container = await payload.findByID({
                        id: slug,
                        collection: 'navigation-containers',
                        depth: 0,
                        ...locale ? {
                            locale
                        } : {}
                    });
                    if (!container) {
                        return res.status(404).json({
                            error: 'Navigation not found'
                        });
                    }
                    // Find all navigation items and handle depth/locale/format
                    const itemsQuery = {
                        collection: 'navigation-items',
                        depth: parseInt(depth || '1', 10),
                        ...locale ? {
                            locale
                        } : {}
                    };
                    // Get all items regardless of parent to build the full tree
                    const itemsResult = await payload.find(itemsQuery);
                    if (!itemsResult?.docs) {
                        return res.status(200).json({
                            ...container,
                            items: []
                        });
                    }
                    // Apply locale filtering if needed
                    const filteredItems = filterItemsByLocale(itemsResult.docs, locale, includeHidden === 'true');
                    // Format the result based on requested format
                    const formattedItems = formatNavigation(container, filteredItems, format || 'tree', currentItemId);
                    // Return the container with the formatted navigation
                    res.status(200).json({
                        ...container,
                        items: formattedItems
                    });
                } catch (error) {
                    next(error);
                }
            }
        }, {
            method: 'patch',
            path: '/api/navigation/:id',
            // @ts-ignore - Endpoint handler type mismatch
            handler: async (req, res, next)=>{
                const payload = req.payload;
                const { id } = req.params;
                const { items } = req.body;
                const { locale } = req.query;
                try {
                    // Find the navigation container
                    const container = await payload.findByID({
                        id,
                        collection: 'navigation-containers',
                        ...locale ? {
                            locale
                        } : {}
                    });
                    if (!container) {
                        return res.status(404).json({
                            error: 'Navigation container not found'
                        });
                    }
                    // Process items to handle the nested structure
                    // This would typically involve updating or creating navigation items
                    // based on the structure, and then updating the container's items field
                    // For simplicity in this example, we'll just update the container's items field
                    // with the IDs of the top-level items
                    const topLevelItemIds = items.map((item)=>item.id);
                    // Update the container with the new items
                    const updatedContainer = await payload.update({
                        id,
                        collection: 'navigation-containers',
                        data: {
                            items: topLevelItemIds
                        },
                        ...locale ? {
                            locale
                        } : {}
                    });
                    res.status(200).json(updatedContainer);
                } catch (error) {
                    next(error);
                }
            }
        }, {
            method: 'get',
            path: '/api/navigation-items/:id',
            // @ts-ignore - Endpoint handler type mismatch
            handler: async (req, res, next)=>{
                const payload = req.payload;
                const { id } = req.params;
                const { depth, locale } = req.query;
                try {
                    // Find the navigation item
                    const navigationItem = await payload.findByID({
                        id,
                        collection: 'navigation-items',
                        depth: parseInt(depth || '1', 10),
                        ...locale ? {
                            locale
                        } : {}
                    });
                    if (!navigationItem) {
                        return res.status(404).json({
                            error: 'Navigation item not found'
                        });
                    }
                    res.status(200).json(navigationItem);
                } catch (error) {
                    next(error);
                }
            }
        }, {
            method: 'patch',
            path: '/api/navigation-items/:id',
            // @ts-ignore - Endpoint handler type mismatch
            handler: async (req, res, next)=>{
                const payload = req.payload;
                const { id } = req.params;
                const itemData = req.body;
                const { locale } = req.query;
                try {
                    // Update the navigation item
                    const updatedItem = await payload.update({
                        id,
                        collection: 'navigation-items',
                        data: itemData,
                        ...locale ? {
                            locale
                        } : {}
                    });
                    res.status(200).json(updatedItem);
                } catch (error) {
                    next(error);
                }
            }
        }, {
            method: 'post',
            path: '/api/navigation-items',
            // @ts-ignore - Endpoint handler type mismatch
            handler: async (req, res, next)=>{
                const payload = req.payload;
                const itemData = req.body;
                const { locale } = req.query;
                try {
                    // Create a new navigation item
                    const newItem = await payload.create({
                        collection: 'navigation-items',
                        data: itemData,
                        ...locale ? {
                            locale
                        } : {}
                    });
                    res.status(201).json(newItem);
                } catch (error) {
                    next(error);
                }
            }
        }, {
            method: 'delete',
            path: '/api/navigation-items/:id',
            // @ts-ignore - Endpoint handler type mismatch
            handler: async (req, res, next)=>{
                const payload = req.payload;
                const { id } = req.params;
                try {
                    // Delete the navigation item
                    await payload.delete({
                        id,
                        collection: 'navigation-items'
                    });
                    res.status(204).send();
                } catch (error) {
                    next(error);
                }
            }
        });
        return config;
    };
// Export types for the plugin
export * from './types/index.js';

//# sourceMappingURL=index.js.map