/**
 * Builds a tree structure of navigation items
 */ export const buildNavigationTree = (container, items, depth = 3)=>{
    // Get the max depth setting from the container or use the provided default
    const maxDepth = container.settings?.maxDepth || depth;
    // Get top-level items (no parent)
    const rootItems = items.filter((item)=>!item.parent).sort((a, b)=>a.order - b.order);
    // Build the tree recursively
    const buildTree = (parentItems, currentDepth = 1)=>{
        if (currentDepth > maxDepth) {
            return [];
        }
        return parentItems.map((item)=>{
            // Find all children of this item
            const children = items.filter((child)=>child.parent === item.id).sort((a, b)=>a.order - b.order);
            // Build path based on type
            let path = '';
            if (item.type === 'external' && item.url) {
                path = item.url;
            } else if (item.type === 'internal' && item.internalLink) {
                // For internal links, use customPath if available, otherwise it would be handled
                // by the frontend resolving the reference
                path = item.internalLink.customPath || '#';
            }
            // Return tree item
            return {
                ...item,
                items: children.length > 0 ? buildTree(children, currentDepth + 1) : [],
                path
            };
        });
    };
    return buildTree(rootItems);
};
/**
 * Builds a flat list of navigation items with level and path information
 */ export const buildFlatNavigation = (container, items)=>{
    const result = [];
    // Recursive function to build flat list
    const buildFlat = (currentItems, level = 0, parentPath = '')=>{
        currentItems.forEach((item)=>{
            // Build path based on type
            let path = '';
            if (item.type === 'external' && item.url) {
                path = item.url;
            } else if (item.type === 'internal' && item.internalLink) {
                path = item.internalLink.customPath || '#';
            }
            // Create flat item with proper type omitting children
            const { children, ...itemWithoutChildren } = item;
            const flatItem = {
                ...itemWithoutChildren,
                level,
                parentPath: parentPath || undefined,
                path
            };
            result.push(flatItem);
            // Process children if any
            const childItems = items.filter((child)=>child.parent === item.id).sort((a, b)=>a.order - b.order);
            if (childItems.length > 0) {
                buildFlat(childItems, level + 1, path);
            }
        });
    };
    // Start with root items
    const rootItems = items.filter((item)=>!item.parent).sort((a, b)=>a.order - b.order);
    buildFlat(rootItems);
    return result;
};
/**
 * Builds a breadcrumb trail to a specific item
 */ export const buildBreadcrumbs = (items, currentItemId)=>{
    if (!currentItemId) {
        return [];
    }
    const breadcrumbs = [];
    // Find the current item
    const currentItem = items.find((item)=>item.id === currentItemId);
    if (!currentItem) {
        return [];
    }
    // Helper function to recursively build breadcrumb trail
    const buildTrail = (item)=>{
        // Build path
        let path = '';
        if (item.type === 'external' && item.url) {
            path = item.url;
        } else if (item.type === 'internal' && item.internalLink) {
            path = item.internalLink.customPath || '#';
        }
        // Add to breadcrumbs
        breadcrumbs.unshift({
            isActive: item.id === currentItemId,
            path,
            title: item.title
        });
        // If this item has a parent, continue up the tree
        if (item.parent) {
            const parentItem = items.find((parent)=>parent.id === item.parent);
            if (parentItem) {
                return buildTrail(parentItem);
            }
        }
        return true;
    };
    buildTrail(currentItem);
    return breadcrumbs;
};
/**
 * Format navigation data based on specified format
 */ export const formatNavigation = (container, items, format = 'tree', currentItemId)=>{
    switch(format){
        case 'breadcrumb':
            return buildBreadcrumbs(items, currentItemId);
        case 'flat':
            return buildFlatNavigation(container, items);
        case 'tree':
        default:
            return buildNavigationTree(container, items);
    }
};
/**
 * Filter items by locale visibility
 */ export const filterItemsByLocale = (items, locale, includeHidden = false)=>{
    // If no locale specified or includeHidden is true, return all items
    if (!locale || includeHidden) {
        return items;
    }
    // Filter items based on active status and locale visibility
    return items.filter((item)=>{
        // Check if item is active, unless we're including hidden items
        if (!item.active && !includeHidden) {
            return false;
        }
        // If no locale visibility settings or empty array, include the item by default
        if (!item.localeVisibility || !Array.isArray(item.localeVisibility) || item.localeVisibility.length === 0) {
            return true;
        }
        // Check if item is visible in the requested locale
        const localeConfig = item.localeVisibility.find((config)=>config && typeof config === 'object' && config.locale === locale);
        // If locale not found in settings, include by default
        // Otherwise check visibility flag
        return !localeConfig || localeConfig.visible !== false;
    });
};

//# sourceMappingURL=formatters.js.map